@@ -1,6 +1,10 @@
-from django.apps import AppConfig
+# -*- encoding: utf-8 -*-
+"""
+Copyright (c) 2019 - present AppSeed.us
+"""
 
+from django.apps import AppConfig
 
 class DynApiConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'apps.dyn_api'
+    name = 'django_dyn_api'
